#ifndef NT2_INCLUDE_FUNCTIONS_PURE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PURE_HPP_INCLUDED

#include <nt2/complex/include/functions/pure.hpp>

#endif
